@@ -69,6 +69,7 @@ def _extract_env_and_vars(parsed):
     with open('dosk.yml') as f:
         datafile = f.readlines()
 
+    env = os.environ.copy()
     for line in datafile:
         try:
             dollar = find(line, '$')
@@ -78,18 +79,17 @@ def _extract_env_and_vars(parsed):
                         end[i] = idx
                         break
                 out = line[int(d + 1):int(end[i])]
-                os.environ[out] = ''
+                if out not in env:
+                    os.environ[out] = ''
         except ValueError:
             pass
 
-    env = os.environ.copy()
-    print(env)
     vars = {}
     if 'vars' in parsed:
         o_vars = parsed['vars']
     vars = json.loads(json.dumps(o_vars))
 
-    return env, vars
+    return vars
 
 async def env_ject(string):
     if string.startswith( '$' ):
@@ -191,7 +191,7 @@ class TaskDefs(dict):
         with open(taskfile) as config:
             yaml = YAML()
             parsed = yaml.load(config)
-            self.env, self.vars = _extract_env_and_vars(parsed)
+            self.vars = _extract_env_and_vars(parsed)
             self.tasks = self._parse_tasks(parsed)
         
     def __getitem__(self, key):
